@@ -1,5 +1,5 @@
 package BalanceOfPower::Role::Analyst;
-$BalanceOfPower::Role::Analyst::VERSION = '0.300000';
+$BalanceOfPower::Role::Analyst::VERSION = '0.300010';
 use strict;
 use v5.10;
 use Moo::Role;
@@ -134,7 +134,7 @@ sub print_near_analysis
             {
                 push @data, { nation => $b,
                               relation => $rel,
-                              how => 'Supported' };
+                              how => 'supported' };
             }
             else
             {
@@ -149,7 +149,7 @@ sub print_near_analysis
                         {
                             push @data, { nation => $b,
                                           relation => $rel,
-                                          how => "Military support from $other_n" };
+                                          how => $other_n };
                         }
                     }
                 }
@@ -256,7 +256,7 @@ sub player_stocks_status
             $market_data{$nation} = { 'stocks' => $player_obj->wallet->{$nation}->{stocks},
                                       'value'  => $self->get_statistics_value(prev_turn($self->current_year), $nation, "w/d"),
                                       'influence' => $player_obj->wallet->{$nation}->{influence},
-                                      'war_bonds' => $player_obj->wallet->{$nation}->{'war bonds'},
+                                      'war_bonds' => $player_obj->wallet->{$nation}->{'war_bonds'},
                                     };
             $stock_value += $player_obj->wallet->{$nation}->{stocks} * $self->get_statistics_value(prev_turn($self->current_year), $nation, "w/d");
         }
