@@ -1,5 +1,5 @@
 package BalanceOfPower::Role::Recorder;
-$BalanceOfPower::Role::Recorder::VERSION = '0.300000';
+$BalanceOfPower::Role::Recorder::VERSION = '0.300010';
 use strict;
 use v5.10;
 
@@ -94,7 +94,7 @@ sub load_players
 sub dump_all
 {
     my $self = shift;
-    my $file = shift;
+    my $file = shift || $self->savefile;
     return "No file provided" if ! $file;
     open(my $io, "> $file");
     $self->dump($io);
@@ -150,6 +150,7 @@ sub load_world
             if($target eq 'WORLD')
             {
                 $world = $self->load($data);
+                $world->savefile($file);
             }
             elsif($target eq 'NATIONS')
             {
